==> qtjambi-qml-debuginfo-macos-6.8.1.jar: sources/QtJambiQml/QQmlIncubationController_shell.cpp <==
#include "QQmlIncubationController_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlIncubationController(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlIncubationController")
    QQmlIncubationController *_ptr = reinterpret_cast<QQmlIncubationController *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlIncubationController_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlIncubationController_shell) ); }

jmethodID QQmlIncubationController_oshell::__shell_javaMethod(int pos) const { return QQmlIncubationController_shell::__shell()->javaMethod(typeid(QQmlIncubationController), pos); }

// emitting (writeShellDestructor)
QQmlIncubationController_shell::~QQmlIncubationController_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlIncubationController::~QQmlIncubationController()", this)
    QQmlIncubationController_shell::__shell()->destructed(typeid(QQmlIncubationController));
}

// emitting (writeShellConstructor)
QQmlIncubationController_shell::QQmlIncubationController_shell()
    : QQmlIncubationController()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlIncubationController::QQmlIncubationController_shell()", this)
    QQmlIncubationController_shell::__shell()->constructed(typeid(QQmlIncubationController));
}

void QQmlIncubationController_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlIncubationController_shell*>(ptr)->QQmlIncubationController_shell::__shell()->tryDeleteShell(typeid(QQmlIncubationController));
}

void QQmlIncubationController_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlIncubationController_oshell*>(ptr)->QQmlIncubationController_oshell::__shell()->tryDeleteShell(typeid(QQmlIncubationController));
}

// emitting Virtual overrides (virtualFunctions)
void QQmlIncubationController_oshell::incubatingObjectCountChanged(int arg__1)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlIncubationController::incubatingObjectCountChanged(int)", this)
        if (JniEnvironmentExceptionHandler __jni_env{300}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlIncubationController_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, arg__1);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlIncubationController_shell::__shell()->warnForMethod("QQmlIncubationController::incubatingObjectCountChanged(int)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QQmlIncubationController::incubatingObjectCountChanged(int)");
            } QTJAMBI_TRY_END
        }else{
            QQmlIncubationController::incubatingObjectCountChanged(static_cast<int>(arg__1));
        }
    }else{
        QQmlIncubationController::incubatingObjectCountChanged(static_cast<int>(arg__1));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QQmlIncubationController_access::__qt_incubatingObjectCountChanged_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QQmlIncubationController::incubatingObjectCountChanged(static_cast<int>(arg__1));
    } else {
        incubatingObjectCountChanged(static_cast<int>(arg__1));
    }
}

// emitting (writeConstructors)
// new QQmlIncubationController()
void __qt_construct_QQmlIncubationController(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlIncubationController()")
    Q_UNUSED(__java_arguments)
    QQmlIncubationController *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QQmlIncubationController_oshell();
    else
        __qt_this = new(__qtjambi_ptr) QQmlIncubationController_shell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlIncubationController::QQmlIncubationController()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlIncubationController_00024Impl_initialize_1native__Lio_qt_qml_QQmlIncubationController_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlIncubationController::QQmlIncubationController()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlIncubationController, sizeof(QQmlIncubationController_shell), typeid(QQmlIncubationController), 0, true, &deleter_QQmlIncubationController, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlIncubationController_shell
void __qt_destruct_QQmlIncubationController(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlIncubationController")
    reinterpret_cast<QQmlIncubationController_shell*>(ptr)->~QQmlIncubationController_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlIncubationController::engine()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlIncubationController_00024Impl_engine_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlIncubationController *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlIncubationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlIncubationController::engine()const", __this_nativeId)
        QQmlEngine* __qt_return_value = __qt_this->QQmlIncubationController::engine();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlIncubationController::incubateFor(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlIncubationController_00024Impl_incubateFor_1native_1int__JI)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jint msecs0)
{
    QTJAMBI_TRY {
        QtJambiExceptionRaiser __qt_exceptionRaiser;
        QQmlIncubationController *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlIncubationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlIncubationController::incubateFor(int)", __this_nativeId)
        __qt_this->QQmlIncubationController::incubateFor(static_cast<int>(msecs0));
        __qt_exceptionRaiser.raise(__jni_env);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlIncubationController::incubateWhile(std::atomic<bool>*,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlIncubationController_00024Impl_incubateWhile_1native_1std_1atomic_1ptr_1int__JLio_qt_qml_QQmlIncubationController_00024WhileFlag_2I)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jobject flag0,
 jint msecs1)
{
    QTJAMBI_TRY {
        QtJambiExceptionRaiser __qt_exceptionRaiser;
        QQmlIncubationController *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlIncubationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlIncubationController::incubateWhile(std::atomic<bool>*,int)", __this_nativeId)
        jlong ptr = Java::QtQml::QQmlIncubationController$WhileFlag::flag(__jni_env, flag0);
        std::atomic<bool>* __qt_flag0 = reinterpret_cast<std::atomic<bool>* >(ptr);
        __qt_this->QQmlIncubationController::incubateWhile(__qt_flag0, static_cast<int>(msecs1));
        __qt_exceptionRaiser.raise(__jni_env);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlIncubationController::incubatingObjectCount()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlIncubationController_00024Impl_incubatingObjectCount_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlIncubationController *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlIncubationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlIncubationController::incubatingObjectCount()const", __this_nativeId)
        __java_return_value = __qt_this->QQmlIncubationController::incubatingObjectCount();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlIncubationController::incubatingObjectCountChanged(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlIncubationController_00024Impl_incubatingObjectCountChanged_1native_1int__JI)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jint arg__1)
{
    QTJAMBI_TRY {
        QQmlIncubationController *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlIncubationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlIncubationController::incubatingObjectCountChanged(int)", __this_nativeId)
        static_cast<QQmlIncubationController_access*>(__qt_this)->__qt_incubatingObjectCountChanged_int(__jni_env, __this_nativeId, arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlIncubationController(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlIncubationController>("QQmlIncubationController", "io/qt/qml/QQmlIncubationController");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo{/* 0 */ "incubatingObjectCountChanged", "(I)V"}});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlIncubationController, {
        ConstructorInfo{&__qt_construct_QQmlIncubationController, nullptr}
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlIncubationController);
    registerSizeOfShell(typeId, sizeof(QQmlIncubationController_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlIncubationController* _object = dynamic_cast<QQmlIncubationController*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlIncubationController *object = reinterpret_cast<QQmlIncubationController *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlIncubationController *object = reinterpret_cast<const QQmlIncubationController *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.8.4.jar: sources/QtJambiQml/QQmlIncubationController_shell.cpp <==
#include "QQmlIncubationController_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlIncubationController(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlIncubationController")
    QQmlIncubationController *_ptr = reinterpret_cast<QQmlIncubationController *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlIncubationController_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlIncubationController_shell) ); }

jmethodID QQmlIncubationController_oshell::__shell_javaMethod(int pos) const { return QQmlIncubationController_shell::__shell()->javaMethod(typeid(QQmlIncubationController), pos); }

// emitting (writeShellDestructor)
QQmlIncubationController_shell::~QQmlIncubationController_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlIncubationController::~QQmlIncubationController()", this)
    QQmlIncubationController_shell::__shell()->destructed(typeid(QQmlIncubationController));
}

// emitting (writeShellConstructor)
QQmlIncubationController_shell::QQmlIncubationController_shell()
    : QQmlIncubationController()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlIncubationController::QQmlIncubationController_shell()", this)
    QQmlIncubationController_shell::__shell()->constructed(typeid(QQmlIncubationController));
}

void QQmlIncubationController_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlIncubationController_shell*>(ptr)->QQmlIncubationController_shell::__shell()->tryDeleteShell(typeid(QQmlIncubationController));
}

void QQmlIncubationController_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlIncubationController_oshell*>(ptr)->QQmlIncubationController_oshell::__shell()->tryDeleteShell(typeid(QQmlIncubationController));
}

// emitting Virtual overrides (virtualFunctions)
void QQmlIncubationController_oshell::incubatingObjectCountChanged(int arg__1)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlIncubationController::incubatingObjectCountChanged(int)", this)
        if (JniEnvironmentExceptionHandler __jni_env{300}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlIncubationController_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, arg__1);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlIncubationController_shell::__shell()->warnForMethod("QQmlIncubationController::incubatingObjectCountChanged(int)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, this, "QQmlIncubationController::incubatingObjectCountChanged(int)");
            } QTJAMBI_TRY_END
        }else{
            QQmlIncubationController::incubatingObjectCountChanged(static_cast<int>(arg__1));
        }
    }else{
        QQmlIncubationController::incubatingObjectCountChanged(static_cast<int>(arg__1));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QQmlIncubationController_access::__qt_incubatingObjectCountChanged_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QQmlIncubationController::incubatingObjectCountChanged(static_cast<int>(arg__1));
    } else {
        incubatingObjectCountChanged(static_cast<int>(arg__1));
    }
}

// emitting (writeConstructors)
// new QQmlIncubationController()
void __qt_construct_QQmlIncubationController(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlIncubationController()")
    Q_UNUSED(__java_arguments)
    QQmlIncubationController *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QQmlIncubationController_oshell();
    else
        __qt_this = new(__qtjambi_ptr) QQmlIncubationController_shell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlIncubationController::QQmlIncubationController()
extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QQmlIncubationController_00024Impl_initialize_1native__Lio_qt_qml_QQmlIncubationController_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlIncubationController::QQmlIncubationController()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlIncubationController, sizeof(QQmlIncubationController_shell), typeid(QQmlIncubationController), 0, true, &deleter_QQmlIncubationController, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlIncubationController_shell
void __qt_destruct_QQmlIncubationController(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlIncubationController")
    reinterpret_cast<QQmlIncubationController_shell*>(ptr)->~QQmlIncubationController_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlIncubationController::engine()const
extern "C" JNIEXPORT jobject JNICALL Java_io_qt_qml_QQmlIncubationController_00024Impl_engine_1native_1constfct__J
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlIncubationController *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlIncubationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlIncubationController::engine()const", __this_nativeId)
        QQmlEngine* __qt_return_value = __qt_this->QQmlIncubationController::engine();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlIncubationController::incubateFor(int)
extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QQmlIncubationController_00024Impl_incubateFor_1native_1int__JI
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jint msecs0)
{
    QTJAMBI_TRY {
        QtJambiExceptionRaiser __qt_exceptionRaiser;
        QQmlIncubationController *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlIncubationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlIncubationController::incubateFor(int)", __this_nativeId)
        __qt_this->QQmlIncubationController::incubateFor(static_cast<int>(msecs0));
        __qt_exceptionRaiser.raise(__jni_env);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlIncubationController::incubateWhile(std::atomic<bool>*,int)
extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QQmlIncubationController_00024Impl_incubateWhile_1native_1std_1atomic_1ptr_1int__JLio_qt_qml_QQmlIncubationController_00024WhileFlag_2I
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jobject flag0,
 jint msecs1)
{
    QTJAMBI_TRY {
        QtJambiExceptionRaiser __qt_exceptionRaiser;
        QQmlIncubationController *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlIncubationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlIncubationController::incubateWhile(std::atomic<bool>*,int)", __this_nativeId)
        jlong ptr = Java::QtQml::QQmlIncubationController$WhileFlag::flag(__jni_env, flag0);
        std::atomic<bool>* __qt_flag0 = reinterpret_cast<std::atomic<bool>* >(ptr);
        __qt_this->QQmlIncubationController::incubateWhile(__qt_flag0, static_cast<int>(msecs1));
        __qt_exceptionRaiser.raise(__jni_env);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlIncubationController::incubatingObjectCount()const
extern "C" JNIEXPORT jint JNICALL Java_io_qt_qml_QQmlIncubationController_00024Impl_incubatingObjectCount_1native_1constfct__J
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlIncubationController *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlIncubationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlIncubationController::incubatingObjectCount()const", __this_nativeId)
        __java_return_value = __qt_this->QQmlIncubationController::incubatingObjectCount();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlIncubationController::incubatingObjectCountChanged(int)
extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QQmlIncubationController_00024Impl_incubatingObjectCountChanged_1native_1int__JI
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jint arg__1)
{
    QTJAMBI_TRY {
        QQmlIncubationController *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlIncubationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlIncubationController::incubatingObjectCountChanged(int)", __this_nativeId)
        static_cast<QQmlIncubationController_access*>(__qt_this)->__qt_incubatingObjectCountChanged_int(__jni_env, __this_nativeId, arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlIncubationController(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlIncubationController>("QQmlIncubationController", "io/qt/qml/QQmlIncubationController");
    registerFunctionInfos(typeId, {
        FunctionInfo{/* 0 */ "incubatingObjectCountChanged", "(I)V"}});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlIncubationController, {
        ConstructorInfo{&__qt_construct_QQmlIncubationController, nullptr}
    });
    registerDeleter(typeId, &deleter_QQmlIncubationController);
    registerSizeOfShell(typeId, sizeof(QQmlIncubationController_shell));
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlIncubationController* _object = dynamic_cast<QQmlIncubationController*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlIncubationController *object = reinterpret_cast<QQmlIncubationController *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlIncubationController *object = reinterpret_cast<const QQmlIncubationController *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
}
